TITLE  "P0101.SAS:                                            ";
TITLE1 "Approximate 95% Confidence Limits for Cronbach's alpha and";
TITLE2 "Intraclass correlation for General Covariance, Gaussian data";
TITLE3 "Use F approximation in Kistner and Muller 2002";

PROC IML ;
%INCLUDE "..\IML\CL1R.IML" /  SOURCE2;
%INCLUDE "..\IML\CL2R.IML" /  SOURCE2;

*Create data matrix, with ;
*N rows as subjects (independent sampling units);
*p columns as variables/items/sub-tests/repeated measures/clusters...;
Y= {1 1 2 3, 
    5 4 5 4, 
    3 2 3 2, 
    2 3 1 1, 
    2 3 3 4, 
    4 3 2 3, 
    1 1 2 2, 
    5 4 3 4, 
    4 3 5 3, 
    2 1 1 3};

*Compute estimated covariance matrix and degrees of freedom; 
YBAR=Y[:,]`;  *Column means;
N=NROW(Y);
P=NCOL(Y);
DF=N-1;       *degrees of freedom of Wishart; 
SIGMAHAT=(Y`*Y- N#YBAR*YBAR`)/DF; *Estimated covariance matrix;
CA_HAT=CALPHA(SIGMAHAT);
ICC_HAT=CA_2_ICC(CA_HAT,P);

*Define desired confidence levels for quantiles;
LEVELS={.025,.975};

/* Using Quantile Approach */
QLOW =ACLREL1(SIGMAHAT,DF,LEVELS[1]);
QLOWCA=QLOW[,1];
QLOWICC=QLOW[,2];
QHIGH=ACLREL1(SIGMAHAT,DF,LEVELS[2]);
QHICA=QHIGH[,1];
QHIICC=QHIGH[,2];
Q=(QLOWCA||CA_HAT||QHICA||QLOWICC||ICC_HAT||QHIICC);


/* Using Confidence Limit Approach */
CLLOW =ACLREL2(SIGMAHAT,DF,LEVELS[1]);
CLOWCA=CLLOW[,1];
CLOWICC=CLLOW[,2];
CLHIGH=ACLREL2(SIGMAHAT,DF,LEVELS[2]);
CHICA=CLHIGH[,1];
CHIICC=CLHIGH[,2];
CL=(CLOWCA||CA_HAT||CHICA||CLOWICC||ICC_HAT||CHIICC);

ROWNM={"Quantiles" };
COLNM={"lower CA" "est CA" "upper CA" "lower ICC" "est ICC" "upper ICC"};
PRINT Q[FORMAT=10.3 COLNAME=COLNM ROWNAME=ROWNM]; 
ROWNM={"Conf. Limit" };
PRINT CL[FORMAT=10.3 COLNAME=COLNM ROWNAME=ROWNM]; 

 


