*TITLE1 "P0301.SAS--plot exact and approximate densities, dots for F"; 
*TITLE2 "Variance = {1 1 1 1}, CS rho=.2, N=10";

FILENAME OUT01 ".\P0301.CGM";

PROC IML WORK=8000 SYMSIZE=8000;
%INCLUDE "..\IML\DENSITY1.IML" /  SOURCE2;

%INCLUDE "..\IML\LIB1.IML"/NOSOURCE2;
%INCLUDE "..\IML\ARLIB1.IML"/NOSOURCE2;
%INCLUDE "..\IML\INTLIB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\AS155LB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\QLIB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\QLIB2.IML" /NOSOURCE2;

*Specify characteristics of data desired;

P=4;
N=10;
RHO=.2;
V_SIGMA={1 1 1 1};
MEAN=0;
PRINT "population values:" N RHO V_SIGMA MEAN ;
MU=J(N,P,MEAN); *Create mean matrix for matrix normal;
*Create an autoregressive covariance matrix;
RHOMAT=RHOCS(P,RHO);
D=DIAG(V_SIGMA);
SIGMA0=D*RHOMAT*D;
CAPOP=CALPHA(SIGMA0);
ICCPOP=CA_2_ICC(CAPOP,P);
PRINT "Sigma:"  SIGMA0;
PRINT "Population value, Cronbach's Alpha:" CAPOP;
PRINT "Population value, ICC:" ICCPOP;

NSTEPS=300;
HIGH=1.25;
*LOW=-1/(P-1);
LOW=-.25;
STEP=(HIGH-LOW)/NSTEPS;
  DO RALPHA=LOW TO HIGH BY STEP;
  EDENS =DENSD01(SIGMA0,RALPHA,N);
  IF RALPHA>1 THEN EDENS=.;
  AFDENS=DENSF01(SIGMA0,RALPHA,N);
  IF RALPHA>1 THEN AFDENS=.;
  AGDENS=DENSN01(SIGMA0,RALPHA,N);
  HOLD1=HOLD1//(RALPHA||EDENS||AFDENS||AGDENS);   
  END;

CNM1={"RALPHA" "EXACT" "FAPPROX" "GAPPROX"};
*PRINT HOLD1 [FORMAT=6.3 COLNAME=CNM1];
CREATE ONE VAR CNM1;
APPEND FROM HOLD1;
CLOSE ONE;

PROC PRINT DATA=ONE UNIFORM;
FORMAT _NUMERIC_ 6.3;

GOPTIONS DISPLAY GSFMODE=REPLACE GACCESS=SASGASTD
         DEVICE=CGMOF97P 
         CBACK=WHITE  COLORS=(BLACK)
         HSIZE=5. IN   VSIZE=3.0 IN
         HTEXT=.16666 IN  HTITLE=.16666 IN  HBY=.16666 IN
         FTEXT="TRIPLEX" FTITLE=TRIPLEX  FBY=TRIPLEX
         HPOS=80 VPOS=60;
SYMBOL1 I=SPLINE V=NONE L=1  W=3;
*SYMBOL2 I=NONE V=CIRCLE H=.166 IN;
SYMBOL3 I=SPLINE V=NONE L=34  W=3;

AXIS1 ORDER=(0 TO 2 BY .5) WIDTH=3 MINOR=NONE MAJOR=(W=3)
            LABEL=(ANGLE=-90 ROTATE=90 "Density");
AXIS2 ORDER=(-.25 TO 1.25  BY .25) WIDTH=3 MINOR=NONE MAJOR=(W=3)
            LABEL=NONE;

GOPTIONS GSFNAME=OUT01;
PROC GPLOT DATA=ONE;
     PLOT (EXACT      GAPPROX)*RALPHA/OVERLAY NOFRAME
                                  VAXIS=AXIS1
                                  HAXIS=AXIS2    ;
RUN;