*TITLE1 "P0304.SAS--plot exact and approximate densities"; 
*TITLE2 "Variance = {1 2 3 4}, AR(1) rho=.8, N=50";

FILENAME OUT01 ".\P0304.CGM";


PROC IML WORK=8000 SYMSIZE=8000;
%INCLUDE "..\IML\DENSITY1.IML" /  SOURCE2;

%INCLUDE "..\IML\LIB1.IML"/NOSOURCE2;
%INCLUDE "..\IML\ARLIB1.IML"/NOSOURCE2;
%INCLUDE "..\IML\INTLIB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\AS155LB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\QLIB1.IML" /NOSOURCE2;
%INCLUDE "..\IML\QLIB2.IML" /NOSOURCE2;

*Specify characteristics of data desired;

P=4;
N=50;
RHO=.8;
V_SIGMA={1 2 3 4};
MEAN=0;
PRINT "population values:" N RHO V_SIGMA MEAN ;
MU=J(N,P,MEAN); *Create mean matrix for matrix normal;
*Create an autoregressive covariance matrix;
RHOMAT=RHOAR1(P,RHO);
D=DIAG(V_SIGMA);
SIGMA0=D*RHOMAT*D;
CAPOP=CALPHA(SIGMA0);
ICCPOP=CA_2_ICC(CAPOP,P);
PRINT "Sigma:"  SIGMA0;
PRINT "Population value, Cronbach's Alpha:" CAPOP;
PRINT "Population value, ICC:" ICCPOP;

NSTEPS=300;
HIGH=1;
*LOW=-1/(P-1);
LOW=.60;
STEP=(HIGH-LOW)/NSTEPS;
  DO RALPHA=LOW TO HIGH BY STEP;
  EDENS =DENSD01(SIGMA0,RALPHA,N);
  AFDENS=DENSF01(SIGMA0,RALPHA,N);
  AGDENS=DENSN01(SIGMA0,RALPHA,N);
  HOLD1=HOLD1//(RALPHA||EDENS||AFDENS||AGDENS);   
  END;

CNM1={"RALPHA" "EXACT" "FAPPROX" "GAPPROX"};
*PRINT HOLD1 [FORMAT=6.3 COLNAME=CNM1];
CREATE ONE VAR CNM1;
APPEND FROM HOLD1;
CLOSE ONE;

PROC PRINT DATA=ONE UNIFORM;
FORMAT _NUMERIC_ 6.3;

GOPTIONS DISPLAY GSFMODE=REPLACE GACCESS=SASGASTD
         DEVICE=CGMOF97P
         CBACK=WHITE  COLORS=(BLACK)
         HSIZE=5. IN   VSIZE=3 IN
         HTEXT=.16666 IN  HTITLE=.16666 IN  HBY=.16666 IN
         FTEXT="TRIPLEX" FTITLE=TRIPLEX  FBY=TRIPLEX
         HPOS=80 VPOS=60;
SYMBOL1 I=SPLINE V=NONE L=1  W=3;
*SYMBOL2 I=SPLINE V=NONE L=33 W=3;
SYMBOL3 I=SPLINE V=NONE L=34  W=3;

AXIS1 ORDER=(0 TO 17.5 BY 2.5) WIDTH=3 MINOR=NONE MAJOR=(W=3)
            LABEL=(ANGLE=-90 ROTATE=90 "Density");
AXIS2 ORDER=(.60 TO 1.0  BY .1) WIDTH=3 MINOR=NONE MAJOR=(W=3)
      LABEL=NONE;

GOPTIONS GSFNAME=OUT01;
PROC GPLOT DATA=ONE;
     PLOT (EXACT GAPPROX)*RALPHA/OVERLAY  NOFRAME
                                  VAXIS=AXIS1
                                  HAXIS=AXIS2    ;
RUN;
