TITLE  "P0102.SAS:                                            ";
TITLE1 "Approximate 95% Confidence Limits for Cronbach's alpha and";
TITLE2 "Intraclass correlation for General Covariance, Gaussian data";
TITLE3 "Use F approximation in Kistner and Muller 2002";
TITLE4 "Assuming Compound Symmetry";

PROC IML ;
%INCLUDE "..\IML\CL1R.IML" /  SOURCE2;
%INCLUDE "..\IML\CL2R.IML" /  SOURCE2;

*Create data matrix, with ;
*N rows as subjects (independent sampling units);
*p columns as variables/items/sub-tests/repeated measures/clusters...;
Y= {1 1 2 3, 
    5 4 5 4, 
    3 2 3 2, 
    2 3 1 1, 
    2 3 3 4, 
    4 3 2 3, 
    1 1 2 2, 
    5 4 3 4, 
    4 3 5 3, 
    2 1 1 3};

*Compute estimated covariance matrix and degrees of freedom; 
YBAR=Y[:,]`;  *Column means;
N=NROW(Y);
P=NCOL(Y);
DF=N-1;       *degrees of freedom of Wishart; 
SIGMAHAT=(Y`*Y- N#YBAR*YBAR`)/DF; *Estimated covariance matrix;
CA_HAT=CALPHA(SIGMAHAT);
ICC_HAT=CA_2_ICC(CA_HAT,P);

*Define desired confidence levels for quantiles;
LEVELS={.025,.975};

/* Using Quantile Approach */
CAQLO=Q_CA_CS(ICC_HAT,P,N,.025);
ICCQLO=CA_2_ICC(CAQLO,P);
CAQHI=Q_CA_CS(ICC_HAT,P,N,.975);
ICCQHI=CA_2_ICC(CAQHI,P);
Q=(CAQLO||CA_HAT||CAQHI||ICCQLO||ICC_HAT||ICCQHI);

/* Using Confidence Limit Approach */
CICCLO=CL_CS(ICC_HAT,P,DF,.025);
CACLO=ICC_2_CA(CICCLO,P);
CICCHI=CL_CS(ICC_HAT,P,DF,.975);
CACHI=ICC_2_CA(CICCHI,P);
CL=(CACLO||CA_HAT||CACHI||CICCLO||ICC_HAT||CICCHI);

ROWNM={"Quantiles" };
COLNM={"lower CA" "est CA" "upper CA" "lower ICC" "est ICC" "upper ICC"};
PRINT Q[FORMAT=10.3 COLNAME=COLNM ROWNAME=ROWNM]; 
ROWNM={"Conf. Limit" };
PRINT CL[FORMAT=10.3 COLNAME=COLNM ROWNAME=ROWNM]; 


